use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Andy
Anwar
ConsoleLogger
Easy
Everywhere
Inc
Jack
LWP
MaxMind
Mohammad
Olaf
Params
UserAgent
Varadinsky
Wireshark
github
lib
olaf
params
simbabque
sromanov
varadinsky
whitelisted
Романов
Сергей
